summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorManoj Srivastava <srivasta@debian.org>2004-03-11 03:44:51 +0000
committerManoj Srivastava <srivasta@debian.org>2004-03-11 03:44:51 +0000
commit178b3ece3e3457fa6fc0acc1c766bd3557dda6cb (patch)
treea4372baeb8182ce98b55f934d85aad0b28269627 /lib
parent9bce92ff39cba298b6549553d08cf0af96c26b8c (diff)
Imported new upstream version
Imported new upstream version git-archimport-id: srivasta@debian.org--2003-primary/tome--upstream--2.2--patch-6
Diffstat (limited to 'lib')
-rw-r--r--lib/core/crpt_aux.lua16
-rw-r--r--lib/core/util.lua21
-rw-r--r--lib/edit/d_info.txt2
-rw-r--r--lib/edit/r_info.txt10
-rw-r--r--lib/edit/v_info.txt10
-rw-r--r--lib/file/news.txt2
-rw-r--r--lib/file/news2.txt2
-rw-r--r--lib/file/rart_f.txt20
-rw-r--r--lib/help/automat.txt2
-rw-r--r--lib/help/c_alchem.txt21
-rw-r--r--lib/help/c_mindcr.txt4
-rw-r--r--lib/help/c_runecr.txt5
-rw-r--r--lib/help/g_manwe.txt4
-rw-r--r--lib/help/g_melkor.txt4
-rw-r--r--lib/help/luckspoi.txt17
-rw-r--r--lib/help/m_mimic.txt4
-rw-r--r--lib/help/m_music.txt2
-rw-r--r--lib/help/rm_barb.txt12
-rw-r--r--lib/help/rm_spec.txt2
-rw-r--r--lib/help/skills.txt44
-rw-r--r--lib/mods/mods_aux.lua3
-rw-r--r--lib/module.lua2
-rw-r--r--lib/scpt/god.lua56
-rw-r--r--lib/scpt/s_manwe.lua6
-rw-r--r--lib/scpt/s_music.lua2
25 files changed, 145 insertions, 128 deletions
diff --git a/lib/core/crpt_aux.lua b/lib/core/crpt_aux.lua
index bbd83661..e00d0b22 100644
--- a/lib/core/crpt_aux.lua
+++ b/lib/core/crpt_aux.lua
@@ -198,22 +198,14 @@ operate when they are activated (whether by player choice or as a random
event). You can check which corruptions do you have in the knowledge screen
6 (accessed through the '~' menu) or in a character dump.
-#####GGaining and losing corruptions
-There are many ways how to gain or lose corruptions.
-
-You can select the *****rm_corru.txt*0[corrupted race] on birth. Such foul
-adventurers will gain and lose corruptions as they gain experience and
-levels. There is a 1 in 3 chance to lose a corruption instead
-of gaining it on these occasions.
+#####GGaining and (not) losing corruptions
+There are several ways that you can become corrupted.
You can become corrupted by quaffing a Potion of Corruption or by drinking
-from Fountain of Corruption. Also some strange items can be activated
+from a Fountain of Corruption. Also some strange items can be activated
for corruption.
-There is 1 in 3 chance you will get corrupted when hit by a chaos attack
-while lacking a source of chaos resistance.
-
-You can also gain and lose corruptions when polymorphing yourself.
+Corruptions are permanent. Once you have one, you have it for life.
]])
local i, e
diff --git a/lib/core/util.lua b/lib/core/util.lua
index c743865a..7920db98 100644
--- a/lib/core/util.lua
+++ b/lib/core/util.lua
@@ -74,7 +74,7 @@ end
-- Returns the direction of the compass that y2, x2 is from y, x
-- the return value will be one of the following: north, south,
-- east, west, north-east, south-east, south-west, north-west,
--- or nil if it is within 2 tiles.
+-- or "close" if it is within 2 tiles.
function compass(y, x, y2, x2)
local y_axis, x_axis, y_diff, x_diff, compass_dir
@@ -102,23 +102,20 @@ function compass(y, x, y2, x2)
x_axis = "west"
end
-
+ -- Maybe it is very close
+ if ((not x_axis) and (not y_axis)) then compass_dir = "close"
-- Maybe it is (almost) due N/S
- if (not x_axis) and (not y_axis) then compass_dir = nil
-
- elseif not x_axis then compass_dir = y_axis
-
+ elseif not x_axis then compass_dir = y_axis
-- Maybe it is (almost) due E/W
- elseif not y_axis then compass_dir = x_axis
-
+ elseif not y_axis then compass_dir = x_axis
-- or if it is neither
- else compass_dir = y_axis.."-"..x_axis
+ else compass_dir = y_axis.."-"..x_axis
end
return compass_dir
end
--- Returns an approximation of the 'distance' of y2, x2 from y, x.
+-- Returns a relative approximation of the 'distance' of y2, x2 from y, x.
function approximate_distance(y, x, y2, x2)
local y_diff, x_diff, most_dist
@@ -147,8 +144,10 @@ function approximate_distance(y, x, y2, x2)
-- how far away then?
if most_dist >= 41 then
+ how_far = "a very long way"
+ elseif most_dist >= 25 then
how_far = "a long way"
- elseif most_dist >= 11 then
+ elseif most_dist >= 8 then
how_far = "quite some way"
else
how_far = "not very far"
diff --git a/lib/edit/d_info.txt b/lib/edit/d_info.txt
index b381c11c..3c4d510f 100644
--- a/lib/edit/d_info.txt
+++ b/lib/edit/d_info.txt
@@ -491,7 +491,7 @@ W:1:50:1:0:14:160
L:1:100:1:0:1:0
A:56:100:56:0:56:0:57:58
O:20:20:20:20
-F:FILL_METHOD_4
+F:FILL_METHOD_4 | NO_RECALL
R:100:0
# N:<index>:<name>
diff --git a/lib/edit/r_info.txt b/lib/edit/r_info.txt
index ecf6614d..4949f66c 100644
--- a/lib/edit/r_info.txt
+++ b/lib/edit/r_info.txt
@@ -1489,9 +1489,9 @@ E:1:1:1:2:1:1
O:0:70:25:0
B:HIT:HURT:1d7
B:HIT:HURT:1d7
-F:MALE |
+F:MALE | GOOD | WILD_TOO | DROP_SKELETON | DROP_CORPSE |
F:FORCE_SLEEP |
-F:DROP_60 | WILD_TOO | DROP_SKELETON | DROP_CORPSE |
+F:DROP_60 |
F:OPEN_DOOR | BASH_DOOR |
F:MORTAL | BASEANGBAND | HAS_LITE
S:1_IN_9 |
@@ -2194,10 +2194,10 @@ E:1:1:1:2:1:1
O:30:55:10:0
B:HIT:HURT:1d7
B:HIT:HURT:1d7
-F:MALE | GOOD | WILD_TOO | DROP_SKELETON | DROP_CORPSE
+F:MALE | GOOD | WILD_TOO | DROP_SKELETON | DROP_CORPSE |
F:FORCE_SLEEP |
F:FRIENDS | DROP_60 |
-F:OPEN_DOOR | BASH_DOOR
+F:OPEN_DOOR | BASH_DOOR |
F:MORTAL | BASEANGBAND | HAS_LITE
S:1_IN_9 |
S:SCARE | CAUSE_1
@@ -5266,7 +5266,7 @@ E:1:1:1:2:1:1
O:20:60:0:10
B:HIT:HURT:4d5
B:HIT:HURT:4d5
-F:MALE | DROP_SKELETON | DROP_CORPSE |
+F:MALE | GOOD | DROP_SKELETON | DROP_CORPSE |
F:DROP_1D2 |
F:TAKE_ITEM | OPEN_DOOR | BASH_DOOR |
F:BASEANGBAND | MORTAL | HAS_LITE
diff --git a/lib/edit/v_info.txt b/lib/edit/v_info.txt
index fbc54475..062fbd49 100644
--- a/lib/edit/v_info.txt
+++ b/lib/edit/v_info.txt
@@ -1801,7 +1801,7 @@ D:%%%%%%%%%%%%%%%%%%%%%
# XXX
-N:82:L.ss.r vault (checker.oard)
+N:82:Lesser vault (checker.oard)
X:7:5:13:21
D:%%%%%%%%%%%%%%%%%%%%%
D:%XXXXXXXXXXXXXXXXXXX%
@@ -1977,7 +1977,7 @@ D:%.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.%
D:%..........................................................%
D:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-N:91:Rounda.out Three
+N:91:Roundabout Three
X:8:30:20:97
D:%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
D:%XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX#XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX%
@@ -2056,7 +2056,7 @@ D:%..###..%
D:%.......%
D:%%%%%%%%%
-N:96:Minor .oss Vault
+N:96:Minor Boss Vault
X:7:3:10:10
D:%%%%%%%%%%
D:%........%
@@ -2069,7 +2069,7 @@ D:%..X++X..%
D:%........%
D:%%%%%%%%%%
-N:97:(Lesser) Major .oss Vault
+N:97:(Lesser) Major Boss Vault
X:7:20:10:10
D:%%%%%%%%%%
D:%........%
@@ -2082,7 +2082,7 @@ D:%..X++X..%
D:%........%
D:%%%%%%%%%%
-N:98:(Greater) Majorly .ossy Vault
+N:98:(Greater) Majorly Bossy Vault
X:8:37:10:10
D:%%%%%%%%%%
D:%........%
diff --git a/lib/file/news.txt b/lib/file/news.txt
index 267b94be..e72edd10 100644
--- a/lib/file/news.txt
+++ b/lib/file/news.txt
@@ -4,7 +4,7 @@
#G // | | | | #W _#r,-"####`-^ #W ) #G || || || ||==:
#G || | | | | #W ,#D###########r`W='#D###W`.#W () #G || || || ||
#G \\_// \ -- / #W ,#D#######################D###W:#r,=. #G || || || \\===
-#G \_/ ===== #W /.#D###W,".#D#####W,".#D###########r"#W##\ #G #ov2.2.5 #G
+#G \_/ ===== #W /.#D###W,".#D#####W,".#D###########r"#W##\ #G #ov2.2.6 #G
#W ,-. _,-= /"._ ,-. #w ," #W `:' `:#D#####W[JW] ,. #G
#W," `," `=._ `" -#w; #G The #W\#D#####W;"' V \#W __,-. ,-=.
#W / " `-. #w / #GTroubles of #W `" `-.#W__,-""._," "--," >-=-
diff --git a/lib/file/news2.txt b/lib/file/news2.txt
index 3f90179a..3e9dec65 100644
--- a/lib/file/news2.txt
+++ b/lib/file/news2.txt
@@ -4,7 +4,7 @@
#G // | | | | #W _#r,-"####`-^ #W ) #G || || || ||==:
#G || | | | | #W ,#D###########r`W='#D###W`.#W () #G || || || ||
#G \\_// \ -- / #W ,#D#######################D###W:#r,=. #G || || || \\===
-#G \_/ ===== #W /.#D###W,".#D#####W,".#D###########r"#W##\ #G #ov2.2.5 #G
+#G \_/ ===== #W /.#D###W,".#D#####W,".#D###########r"#W##\ #G #ov2.2.6 #G
#W ,-. _,-= /"._ ,-. #w ," #W `:' `:#D#####W[JW] ,. #G
#W," `," `=._ `" -#w; #G The #W\#D#####W;"' V \#W __,-. ,-=.
#W / " `-. #w / #G Tales of #W `" `-.#W__,-""._," "--," >-=-
diff --git a/lib/file/rart_f.txt b/lib/file/rart_f.txt
index 17012f21..3bebf94d 100644
--- a/lib/file/rart_f.txt
+++ b/lib/file/rart_f.txt
@@ -4,7 +4,7 @@ Kenault's Cantrip Generator
The Deck of Wild Magic
Baalzebub's Tormented Box
Baalzebub's All-seeing Servant
-Boccob's Unifinished Works
+Boccob's Unfinished Works
The Gem of Fire
The Gem of Ice
The Gem of Venom
@@ -57,21 +57,21 @@ Boccob's Magical Mish-mash
The Grail of Kenault
a Parchment titled ``Household Magic''
a Parchment titled ``Tenser's Last Words''
-the Hand of Vecna
-the Skull of Vecna
-the Eye of Vecna
-the Crystal Ball of The Witch-King of Angmar
+The Hand of Vecna
+The Skull of Vecna
+The Eye of Vecna
+The Crystal Ball of The Witch-King of Angmar
a Parchment titled ``Secrets of the Gnomish Wizards''
-the Medallion of Good Will
-the Immortal Skull of Benetar
+The Medallion of Good Will
+The Immortal Skull of Benetar
Heward's Excellent Experimental Earmuffs
Bigby's Big Book of Brutality
The Cunning Plan of Zog
-A parchment titled ''Immortality For Dummies''
+a Parchment titled ''Immortality For Dummies''
Raistlin's Ready Ranger
Tenser's Torch of Spontaneous Combustion
Mordenkainen's Mysterious Mind-Masher
-A parchment titled ''Famous Last Words''
+a Parchment titled ''Famous Last Words''
Jor's Buckler of Missile Attraction
Jor's Compendium of Strange Behaviour
Agannazar's Antique Acorn
@@ -79,7 +79,7 @@ Cathal's Corrupting Cymbal
Pytar's Portable Pandemonium
The Toenail of Vecna
Jor's Book of Impossible Occurences
-A parchment titled ''Finer Points of Munchkinism''
+a Parchment titled ''Finer Points of Munchkinism''
Agannazar's Altruistic Assassin
Tenser's Top-Heavy Teaspoon
Olive's Omnipotent Ostrich
diff --git a/lib/help/automat.txt b/lib/help/automat.txt
index 8530c228..01ba714e 100644
--- a/lib/help/automat.txt
+++ b/lib/help/automat.txt
@@ -493,7 +493,7 @@ before I talk you through it
&&&&&B\B-B-B-B-B-B-B-B-B-B-B-B-B-B-B/w RkW WtWoW rdrirsrarbrlreW WtWhWeW WaWuWtWoWmWaWtWiWzWeWrw w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w w
The majority of this is fairly similar to the swords rule; it destroys {average}
-swords at character level 20, {good} ones at character level 35 and cursed ones
+boots at character level 20, {good} ones at character level 35 and cursed ones
always. The addition is at the bottom. It adds clauses which will destroy
excellent items providing that they have been identified and that the name does
not contain the word "speed". The <state>identified</state> bit is important
diff --git a/lib/help/c_alchem.txt b/lib/help/c_alchem.txt
index fb2cf8f9..66c11843 100644
--- a/lib/help/c_alchem.txt
+++ b/lib/help/c_alchem.txt
@@ -39,7 +39,7 @@ Combat 1.000 [0.700]
Sneakiness 1.000 [0.900]
Magic 3.000 [0.900]
Magic-Device 0.000 [0.250]
- Geomancy 0.000 [0.500]
+ Geomancy
Fire 0.000 [0.100]
Water 0.000 [0.100]
Air 0.000 [0.100]
@@ -58,6 +58,9 @@ Spirituality 1.000 [0.800]
Prayer 0.000 [0.500]
Monster-lore 0.000 [0.500]
+*An Alchemist cannot learn the Geomancy skill, but it is shown in his skill
+screen because the elemental schools are sub-skills of it.
+
#####GInnate Abilities:
#####BAbility Character level
Perfect-casting 1
@@ -107,19 +110,19 @@ gold to improve the chances of his success.
[[[[[BA few pointers:]
-Recipes are (usually) logical. Acid essences don't make Dragon
Weapons. And you can always look at the recipes you know with
- the 'B'ook command.
+ the 'B'ook command.
-Not all objects or ego-item types can be made using alchemy.
-Alchemy is mostly reversible. Most items that you can
- 'E'xtract from, you can later re-create, if you learn about
- them when extracting from them. You won't always get enough
- essences from destroying an item to recreate it, though the
- chance of doing so will get higher as you increase in skill.
+ 'E'xtract from, you can later re-create, if you learn about
+ them when extracting from them. You won't always get enough
+ essences from destroying an item to recreate it, though the
+ chance of doing so will get higher as you increase in skill.
-*identifying* an object that you can destroy will always teach
- you how to create it (if creating it is possible).
+ you how to create it (if creating it is possible).
-Since you can't create abilities in artifacts that you aren't
- aware of, make sure to *identify* all the artifacts you can.
+ aware of, make sure to *identify* all the artifacts you can.
-You can't *identify* things you buy in shops, so you'll have
- to extract from them and take your chances.
+ to extract from them and take your chances.
[[[[[BSome Recipes:]
Any alchemist worth his salt knows lots of recipes. By extracting from
diff --git a/lib/help/c_mindcr.txt b/lib/help/c_mindcr.txt
index 9c846ae3..d6ff5496 100644
--- a/lib/help/c_mindcr.txt
+++ b/lib/help/c_mindcr.txt
@@ -52,6 +52,4 @@ powers in the *****m_mindcr.txt*0[Mindcraft powers] document.
#####GStarting Equipment
A mindcrafter begins the game with:
- A small sword
- A potion of restore mana
- Soft leather armor
+ A mace
diff --git a/lib/help/c_runecr.txt b/lib/help/c_runecr.txt
index d6adf765..9cf2a2ec 100644
--- a/lib/help/c_runecr.txt
+++ b/lib/help/c_runecr.txt
@@ -33,7 +33,7 @@ Magic 2.000 [0.950]
Magic-Device 1.000 [1.200]
Spell-power 0.000 [0.600]
Mana 1.000 [0.600]
- Geomancy 0.000 [0.000]
+ Geomancy
Fire 0.000 [0.700]
Water 0.000 [0.700]
Air 0.000 [0.700]
@@ -51,6 +51,9 @@ Spirituality 1.000 [0.550]
Prayer 0.000 [0.500]
Monster-lore 0.000 [0.500]
+*A Runecrafter cannot learn the Geomancy skill, but it is shown in his skill
+screen because the elemental schools are sub-skills of it.
+
#####GInnate Abilities:
#####BAbility Character level
Perfect-casting 1
diff --git a/lib/help/g_manwe.txt b/lib/help/g_manwe.txt
index 9e042b47..da11f809 100644
--- a/lib/help/g_manwe.txt
+++ b/lib/help/g_manwe.txt
@@ -34,7 +34,7 @@ There is a special book - called the "Holy Tome of Manwe Sulimo" which
contains instructions for the procedure for each of the prayers Manwe will
grant. There are four prayers all told, which are:
1. [[[[[BManwe's Blessing] (Level 1)
- Manwe's Blessing removes your fears, bless you and surrounds you with holy
+ Manwe's Blessing removes your fears, blesses you and surrounds you with holy
light.
At spell level 10 it also grants heroism.
At spell level 20 it also grants super heroism.
@@ -42,7 +42,7 @@ grant. There are four prayers all told, which are:
2. [[[[[BWind Shield] (Level 10)
It surrounds you with a shield of wind that deflects blows from evil
monsters.
- At level 10 it increases your armor rating.
+ At level 10 it increases your armour rating.
At level 20 it retaliates against monsters that melee you.
3. [[[[[BManwe's Call] (Level 20)
Manwe's Call summons a Great Eagle to help you battle the forces of
diff --git a/lib/help/g_melkor.txt b/lib/help/g_melkor.txt
index f7e2fc76..2a28658f 100644
--- a/lib/help/g_melkor.txt
+++ b/lib/help/g_melkor.txt
@@ -9,12 +9,12 @@ of the Valar. His most faithful followers are those of the class *****c_pr_drk.t
#####GThe benefits of Worshipping Melkor Bauglir
1. As you increase your piety, Melkor will grant boosts to your strength,
constitution and charisma and will decrease intelligence and wisdom.
- 2. If you are praying, Melkor may makes you invisible and immune to fire.
+ 2. If you are praying, Melkor may make you invisible and immune to fire.
3. If you are praying, Melkor may cast Curse on your foes when you melee them.
4. If you are praying, Melkor likes it when you kill monsters.
5. If you are praying, Melkor *likes* it when you kill monsters that are
aligned with good.
- 6. Melkor likes sacrifice of corpse and books at his altars.
+ 6. Melkor likes the sacrifice of corpses and books at his altars.
7. Melkor likes the permanent sacrifice of your own health at his altars.
8. Melkor hates elves.
9. Melkor grants access to the *****m_udun.txt*0[Udun] school of magic.
diff --git a/lib/help/luckspoi.txt b/lib/help/luckspoi.txt
index b0fcc312..4791d1a6 100644
--- a/lib/help/luckspoi.txt
+++ b/lib/help/luckspoi.txt
@@ -25,10 +25,10 @@ below from most luck to least luck.
Barbarian (+1);
Spectre, Skeleton (-3);
-Vampire, Zombie (-4).
+Zombie (-4).
-So, a Hobbit Barbarian starts with 6 luck points, while a Yeek Zombie starts
-with -9 luck points.
+So, a Hobbit starts with 5 luck points, a Beorning Barbarian starts with 2 luck
+points, while a Yeek Zombie starts with -9 luck points.
#####G2. Descriptions
Drinking a potion of self-knowledge will tell you how lucky or unlucky your
@@ -56,7 +56,7 @@ All Morgul items have -10 luck.
Artifacts can affect your luck. Beware: not all artifacts give you good luck.
Listed below are the artifacts which affect your luck.
-Phial of Galadriel (+4)
+The Phial of Galadriel (+4)
The Arkenstone of Thrain (+3)
The Ring of Power 'Narya' (+1)
The Ring of Power 'Nenya' (+2)
@@ -69,17 +69,19 @@ The Long Bow of Bard (+2)
The Mage Staff of Eternity (+12)
The Harp of Maglor (+3)
The Drum of the Sky (+2)
-The Flute of Daeron (+1)
+The Harp of Daeron (+1)
The Long Sword of Eternity (+10)
The Robe of Great Luck (+60)
The Heavy Crossbow of Eternity (+5)
The Iron Helm of Knowledge (-6)
The Shield of Deflection of Gil-galad (+5)
The Set of Gauntlets of Eol (+3)
+The Demonblade of Gothmog (-20)
+The Long Sword 'Durandil' (+3)
The Phial of Undeath (-5)
The Ring of Phasing (+15)
The Blue Stone 'Toris Mejistos' (+2)
-The Demonblade of Gothmog (-20)
+
#####G4. What does it affect.
It affects your chance to-hit in ranged combat and melee combat.
@@ -101,7 +103,8 @@ It affects the chance of creating a special object.
It prevents the death fate if your are lucky.
-It affects the number of skills you receive when quaffing a potion of skill.
+It affects the number of skill points you receive when quaffing the Potion of
+Learning.
Written for ToME 2.0 by Chris Hadgis
diff --git a/lib/help/m_mimic.txt b/lib/help/m_mimic.txt
index 39fafa7d..78efdff3 100644
--- a/lib/help/m_mimic.txt
+++ b/lib/help/m_mimic.txt
@@ -13,7 +13,7 @@ overridden during the shape-shift.
As your mimicry skill increases, your character is less likely to spoil
the transformation attempt and may even gain other powers, such as making
his colouration match his surroundings (becoming in all respects invisible)
-or even stranger abilities... rumors abound about Tarka the Chameleon and
+or even stranger abilities... rumours abound about Tarka the Chameleon and
her two pairs of boots of speed.
The powers are accessed using the 'm' key and then selecting 'Use Mimicry';
@@ -30,5 +30,5 @@ as usual through the *****skills.txt*21[Magic] skill.
Allows you to move within walls, and [[[[[Bonly] walls for a time.
[[[[[v Be careful you don't get stuck in a wall when it runs out.]
5. [[[[[sArms Mimicry] (Level 35) Cost:100
- Gives you an additional set of armsfor a time.
+ Gives you an additional set of arms for a time.
diff --git a/lib/help/m_music.txt b/lib/help/m_music.txt
index 9ed1d90e..82cfbfeb 100644
--- a/lib/help/m_music.txt
+++ b/lib/help/m_music.txt
@@ -46,7 +46,7 @@ of instrument contains a different family of musical songs:
1. [[[[[vSong of the Sun(I)] (School level 1)
Provides light as long as you sing.
Consumes the amount of mana each turn.
-2. [[[[[vFlow of Life(I)] (School level 5)
+2. [[[[[vFlow of Life(II)] (School level 5)
Heals you as long as you sing.
Consumes the amount of mana each turn.
3. [[[[[vHeroic Ballad(II)] (School level 10)
diff --git a/lib/help/rm_barb.txt b/lib/help/rm_barb.txt
index 011845ec..d4a35728 100644
--- a/lib/help/rm_barb.txt
+++ b/lib/help/rm_barb.txt
@@ -4,10 +4,10 @@
#####GDescription
Barbarians are hardy members of their race. They are fierce in combat, and
-their wrath is feared throughout the world. Combat is their life: they feel
-no fear, and they learn to enter battle frenzy at will. Barbarians are,
-however, suspicious of magic, which makes magic devices fairly hard for
-them to use, and also makes it impossible for them to play Mages.
+their wrath is feared throughout the world. Combat is their life: they learn
+to feel no fear. Barbarians are, however, suspicious of magic, which makes
+magic devices fairly hard for them to use, and also makes it impossible for
+them to play Mages.
#####GStat Modifiers
Strength +2
@@ -23,6 +23,4 @@ Exp Penalty +25%
A barbarian character begins the game with:
Some rations
Some torches
- Changes ring of resist fear (*IF* the character would have had one)
- to a ring of sustain strength.
-
+ \ No newline at end of file
diff --git a/lib/help/rm_spec.txt b/lib/help/rm_spec.txt
index f54d0a55..ed8723bb 100644
--- a/lib/help/rm_spec.txt
+++ b/lib/help/rm_spec.txt
@@ -7,7 +7,7 @@
Another powerful undead creature: the spectre is a ghastly apparition,
surrounded by an unearthly glow. They exist only partially on our
plane of existence: half-corporeal, they can pass through walls, though
-this takes requires a sacrifice of some of their life-force. As a result
+this requires a sacrifice of some of their life-force. As a result
they cannot rest whilst passing through a wall.
As undead, they have a firm hold on their life force, see invisible, and
resist poison and cold. They also resist nether. Spectres make superb
diff --git a/lib/help/skills.txt b/lib/help/skills.txt
index 4666d044..c6c244ac 100644
--- a/lib/help/skills.txt
+++ b/lib/help/skills.txt
@@ -100,24 +100,24 @@ spend you're hard-earned points, huh? Well, each skill affects different
abilities, and not all of them are intuitive - but they don't take all that
long to learn :).
If you don't find this informative enough, and would like more detailed spoilers
-on what each skill does, try [[[[[ghttp://www.killerbunnies.org/angband/skill.html] for
-some third party help!
+on what each skill does, try [[[[[ghttp://www.killerbunnies.org/angband/skill-220.html]
+for some third party help!
The skills are:
*****skills.txt*27[Air] *****skills.txt*49[Alchemy] *****skills.txt*50[Antimagic] *****skills.txt*08[Archery]
- *****skills.txt*05[Axe-mastery] *****skills.txt*18[Backstab] *****skills.txt*13[Barehand-combat] *****skills.txt*12[Boomerang-mastery]
- *****skills.txt*58[Boulder-throwing] *****skills.txt*10[Bow-mastery] *****skills.txt*01[Combat] *****skills.txt*30[Conveyance]
- *****skills.txt*44[Corpse-preservation] *****skills.txt*04[Critical-hits] *****skills.txt*11[Crossbow-mastery] *****skills.txt*52[Demonology]
- *****skills.txt*16[Disarming] *****skills.txt*31[Divination] *****skills.txt*20[Dodging] *****skills.txt*28[Earth]
- *****skills.txt*25[Fire] *****skills.txt*60[Geomancy] *****skills.txt*06[Hafted-mastery] *****skills.txt*21[Magic]
- *****skills.txt*54[Magic-Device] *****skills.txt*24[Mana] *****skills.txt*29[Meta] *****skills.txt*47[Mimicry]
- *****skills.txt*33[Mind] *****skills.txt*41[Mindcraft] *****skills.txt*42[Monster-lore] *****skills.txt*59[Music]
- *****skills.txt*34[Nature] *****skills.txt*35[Necromancy] *****skills.txt*07[Polearm-mastery] *****skills.txt*45[Possession]
- *****skills.txt*39[Prayer] *****skills.txt*36[Runecraft] *****skills.txt*09[Sling-mastery] *****skills.txt*14[Sneakiness]
- *****skills.txt*22[Spell-power] *****skills.txt*38[Spirituality] *****skills.txt*23[Sorcery] *****skills.txt*19[Stealing]
- *****skills.txt*15[Stealth] *****skills.txt*53[Stunning-blows] *****skills.txt*43[Summoning] *****skills.txt*03[Sword-mastery]
- *****skills.txt*46[Symbiosis] *****skills.txt*32[Temporal] *****skills.txt*37[Thaumaturgy] *****skills.txt*48[Udun]
- *****skills.txt*26[Water] *****skills.txt*02[Weaponmastery]
+ *****skills.txt*05[Axe-mastery] *****skills.txt*18[Backstab] *****skills.txt*13[Barehand-combat] *****skills.txt*61[Bearform-combat]
+ *****skills.txt*12[Boomerang-mastery] *****skills.txt*58[Boulder-throwing] *****skills.txt*10[Bow-mastery] *****skills.txt*01[Combat]
+ *****skills.txt*30[Conveyance] *****skills.txt*44[Corpse-preservation]*****skills.txt*04[Critical-hits] *****skills.txt*11[Crossbow-mastery]
+ *****skills.txt*52[Demonology] *****skills.txt*16[Disarming] *****skills.txt*31[Divination] *****skills.txt*20[Dodging]
+ *****skills.txt*28[Earth] *****skills.txt*25[Fire] *****skills.txt*60[Geomancy] *****skills.txt*06[Hafted-mastery]
+ *****skills.txt*21[Magic] *****skills.txt*54[Magic-device] *****skills.txt*24[Mana] *****skills.txt*29[Meta]
+ *****skills.txt*47[Mimicry] *****skills.txt*33[Mind] *****skills.txt*41[Mindcraft] *****skills.txt*42[Monster-lore]
+ *****skills.txt*59[Music] *****skills.txt*34[Nature] *****skills.txt*35[Necromancy] *****skills.txt*07[Polearm-mastery]
+ *****skills.txt*45[Possession] *****skills.txt*39[Prayer] *****skills.txt*36[Runecraft] *****skills.txt*09[Sling-mastery]
+ *****skills.txt*14[Sneakiness] *****skills.txt*22[Spell-power] *****skills.txt*38[Spirituality] *****skills.txt*23[Sorcery]
+ *****skills.txt*19[Stealing] *****skills.txt*15[Stealth] *****skills.txt*53[Stunning-blows] *****skills.txt*43[Summoning]
+ *****skills.txt*03[Sword-mastery] *****skills.txt*46[Symbiosis] *****skills.txt*32[Temporal] *****skills.txt*37[Thaumaturgy]
+ *****skills.txt*48[Udun] *****skills.txt*26[Water] *****skills.txt*02[Weaponmastery]
~~~~~01|Skills|Combat
@@ -227,6 +227,11 @@ This skill is a sub-skill of the Combat skill. It affects your general ability
to fight using martial arts. In order to utilise it, you must be capable of
using a weapon in the first place, but choose not to. Spending 1 skill point
on your Barehand-combat skill adds 0.5 bonus skill points to your Combat skill.
+~~~~~61|Skills|Bearform-combat
+[[[[[BBearform-combat]
+This skill is a sub-skill of the Combat skill. It affects your ability to fight
+while in the form of a bear. In order to utilise it, you must be in bearform.
+*****r_beorn*0[Beornings] are the adventurers most likely to use this form of skill.
~~~~~58|Skills|Boulder-throwing
[[[[[BBoulder-throwing]
This skill is a sub-skill of the Combat skill. It affects your ability to
@@ -292,15 +297,15 @@ the strength of wands and staffs.
Investing in the Magic skill? You might be interested in the *****ability.txt*04[Perfect Casting]
ability.
-Sub-skills include: Magic-Device, Spell-power, Sorcery, Mana, Fire, Water, Air,
+Sub-skills include: Magic-device, Spell-power, Sorcery, Mana, Fire, Water, Air,
Earth, Meta, Conveyance, Divination, Temporal, Mind, Nature, Udun, Demonology,
Necromancy, Runecraft, Thaumaturgy, and Alchemy.
-~~~~~54|Skills|Magic-Device
-[[[[[BMagic-Device]
+~~~~~54|Skills|Magic-device
+[[[[[BMagic-device]
This skill is a sub-skill of the Magic skill. It eases the use of magical
devices, such as wands, staves, and rods, and boosts the casting level of spells
stored in a wand or a staff. *****magic.txt*02[More on this]. It also helps pseudo-id of magic
-objects. Spending 1 skill point on your Magic-Device skill adds 0.07 bonus skill
+objects. Spending 1 skill point on your Magic-device skill adds 0.07 bonus skill
points to your Magic skill.
~~~~~22|Skills|Spell-power
[[[[[BSpell-power]
@@ -477,6 +482,7 @@ available under the "m" menu. Spending 1 skill point on your Mindcraft skill
adds 0.1 bonus skill points to your Spirituality skill and 0.1 bonus skill
points to your Magic skill.
~~~~~59|Skills|Music
+[[[[[BMusic]
This skill is a sub-skill of the Spirituality skill. It affects what level of
*****m_music.txt*0[Musical songs] you can access through instruments. This power
is available under the "m" menu. Spending 1 skill point on your Music skill
diff --git a/lib/mods/mods_aux.lua b/lib/mods/mods_aux.lua
index e04ed472..48bc7da1 100644
--- a/lib/mods/mods_aux.lua
+++ b/lib/mods/mods_aux.lua
@@ -1,4 +1,5 @@
-- Ok some functions that we dont need are dangerous
+--[[
execute = nil
getenv = nil
setlocale = nil
@@ -10,7 +11,7 @@ appendto = nil
remove = nil
rename = nil
tmpname = nil
-
+]]
modules = {}
current_module = nil
diff --git a/lib/module.lua b/lib/module.lua
index 9fe05e30..af1c9337 100644
--- a/lib/module.lua
+++ b/lib/module.lua
@@ -1,7 +1,7 @@
add_module
{
["name"] = "ToME",
- ["version"] = { 2, 2, 5 },
+ ["version"] = { 2, 2, 6 },
["author"] = { "DarkGod", "darkgod@t-o-m-e.net" },
["desc"] = {
"The Tales of Middle-earth, the standard and official game.",
diff --git a/lib/scpt/s_manwe.lua b/lib/scpt/s_manwe.lua
index 38be533f..6f0f9661 100644
--- a/lib/scpt/s_manwe.lua
+++ b/lib/scpt/s_manwe.lua
@@ -41,7 +41,7 @@ MANWE_SHIELD = add_spell
end,
["desc"] = {
"It surrounds you with a shield of wind that deflects blows from evil monsters",
- "At level 10 it increases your armor rating",
+ "At level 10 it increases your armour rating",
"At level 20 it retaliates against monsters that melee you",
}
}
@@ -103,8 +103,8 @@ MANWE_BLESS = add_spell
return "dur "..(get_level(MANWE_BLESS, 70) + 30).."+d40"
end,
["desc"] = {
- "Manwe's Blessing removes your fears, bless you and surrounds you with",
- "holy lite",
+ "Manwe's Blessing removes your fears, blesses you and surrounds you with",
+ "holy light",
"At level 10 it also grants heroism",
"At level 20 it also grants super heroism",
"At level 30 it also grants holy luck and life protection",
diff --git a/lib/scpt/s_music.lua b/lib/scpt/s_music.lua
index 5e857495..9da6393a 100644
--- a/lib/scpt/s_music.lua
+++ b/lib/scpt/s_music.lua
@@ -430,7 +430,7 @@ MUSIC_ = add_spell
["random"] = SKILL_MUSIC,
["pval"] = 1,
["spell"] = function()
-
+
return TRUE
end,
["info"] = function()
diff --git a/lib/scpt/god.lua b/lib/scpt/god.lua
index b27ca2a3..31e92183 100644
--- a/lib/scpt/god.lua
+++ b/lib/scpt/god.lua
@@ -17,18 +17,26 @@ add_quest
["global"] = "GOD_QUEST",
["name"] = "God quest",
["desc"] = function()
- local home, home_axis, player_axis
if quest(GOD_QUEST).status == QUEST_STATUS_TAKEN then
-- get the direction that the dungeon lies from lothlorien/angband
- player_axis, home, home_axis = get_god_quest_axes()
+ local home, home_axis, home_distance, home2, home2_axis, home2_distance = get_god_quest_axes()
print_hook("#####yGod quest!\n")
print_hook("Thou art to find the lost temple of thy God and\n");
print_hook("to retrieve the lost part of the relic for thy God! \n")
- print_hook("The temple lies to the "..home_axis.." of "..home.." \n")
- print_hook("and to the "..player_axis.." of thy position when thou were given the quest. \n")
+ -- print_hook("home_axis = "..home_axis.." home2_axis = "..home2_axis)
+ if home_axis ~= "close" then
+ print_hook("The temple lies "..home_distance.." to the "..home_axis.." of "..home..", \n")
+ else
+ print_hook("The temple lies very close to "..home..", \n")
+ end
+ if home2_axis ~= "close" then
+ print_hook( "and "..home2_distance.." to the "..home2_axis.." of "..home2..", I can feel it.' \n")
+ else
+ print_hook("and very close to "..home2..", I can feel it.' \n")
+ end
print_hook("\n")
end
end,
@@ -100,7 +108,7 @@ add_quest
god_quest.player_y, god_quest.player_x = player.get_wild_coord()
-- establish direction of player and 'home' from dungeon
- local player_axis, home, home_axis, distance = get_god_quest_axes()
+ local home, home_axis, home_distance, home2, home2_axis, home2_distance = get_god_quest_axes()
-- God issues instructions
cmsg_print(TERM_L_BLUE, "The voice of "..deity(player.pgod).name.." booms in your head:")
@@ -111,16 +119,16 @@ add_quest
cmsg_print(TERM_YELLOW, "Thou art to find my lost temple and retrieve a piece of the relic.")
cmsg_print(TERM_YELLOW, "When thy task is done, thou art to lift it in the air and call upon my name.")
cmsg_print(TERM_YELLOW, "I shall then come to reclaim what is mine!")
- if player.axis then
- cmsg_print(TERM_YELLOW, "The temple lies "..distance.." to the "..player_axis.." of thy current position,")
+ if home_axis ~= "close" then
+ cmsg_print(TERM_YELLOW, "The temple lies "..home_distance.." to the "..home_axis.." of "..home..", ")
else
- cmsg_print(TERM_YELLOW, "The temple lies "..distance.." from thy current position,")
+ cmsg_print(TERM_YELLOW, "The temple lies very close to "..home..",")
end
- if home_axis then
- cmsg_print(TERM_YELLOW, "and to the "..home_axis.." of "..home..", I can feel it.'")
+ if home2_axis ~= "close" then
+ cmsg_print(TERM_YELLOW, "and "..home2_distance.." to the "..home2_axis.." of "..home2..", I can feel it.'")
else
- cmsg_print(TERM_YELLOW, "and very close to "..home..", I can feel it.'")
+ cmsg_print(TERM_YELLOW, "and very close to "..home2..", I can feel it.'")
end
-- Prepare depth of dungeon. If this was generated in set_god_dungeon_attributes(),
@@ -553,27 +561,33 @@ end
-- Calling this function returns the direction the dungeon is in from the players position at the time
-- the quest was given, and also the direction from angband (if the player is worshipping Melkor) or lothlorien.
function get_god_quest_axes()
- local play_y_coord, play_x_coord, y_axis, x_axis, player_axis, home_axis, mydistance
-
- player_axis = compass(god_quest.player_y, god_quest.player_x, god_quest.dung_y, god_quest.dung_x)
+ local home, home_y_coord, home_x_coord, home_axis, home2, home2_y_coord, home2_x_coord, home2_axis, mydistance
-- different values for different gods...
if player.pgod ~= GOD_MELKOR then
- -- one of the valar, "home" is lothlorien
- home = "Lothlorien"
- home_y_coord = 34
- home_x_coord = 50
+ -- one of the valar, "home" is lothlorien, home2 is Minas Arnor
+ home = "Bree"
+ home_y_coord = 21
+ home_x_coord = 34
+ home2 = "Minas Anor"
+ home2_y_coord = 56
+ home2_x_coord = 60
else
- -- Melkor, "home" is angband
+ -- Melkor, "home" is angband, home2 is Barad-dur
home = "the Pits of Angband"
home_y_coord = 7
home_x_coord = 34
+ home2 = "the stronghold of Barad-Dur"
+ home2_y_coord = 51
+ home2_x_coord = 71
end
home_axis = compass(home_y_coord, home_x_coord, god_quest.dung_y, god_quest.dung_x)
+ home2_axis = compass(home2_y_coord, home2_x_coord, god_quest.dung_y, god_quest.dung_x)
- mydistance = approximate_distance(god_quest.player_y, god_quest.player_x, god_quest.dung_y, god_quest.dung_x)
+ home_distance = approximate_distance(home_y_coord, home_x_coord, god_quest.dung_y, god_quest.dung_x)
+ home2_distance = approximate_distance(home2_y_coord, home2_x_coord, god_quest.dung_y, god_quest.dung_x)
- return player_axis, home, home_axis, mydistance
+ return home, home_axis, home_distance, home2, home2_axis, home2_distance
end